import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useRef, useMemo, useEffect, useContext } from 'react';
import classnames from 'classnames';
import { isDef, addUnit } from '../utils';
import Icon from '../icon';
import { useSetState, useUpdateEffect } from '../hooks';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var Image = function Image(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('image', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var fit = props.fit,
      errorIcon = props.errorIcon,
      loadingIcon = props.loadingIcon,
      showError = props.showError,
      showLoading = props.showLoading,
      block = props.block;

  var _useSetState = useSetState({
    loading: true,
    error: false
  }),
      _useSetState2 = _slicedToArray(_useSetState, 2),
      status = _useSetState2[0],
      setStatus = _useSetState2[1];

  var imgRef = useRef(null);
  var unmountedRef = useRef(false);
  var style = useMemo(function () {
    var internalStyle = {};

    if (isDef(props.width)) {
      internalStyle.width = addUnit(props.width);
    }

    if (isDef(props.height)) {
      internalStyle.height = addUnit(props.height);
    }

    if (isDef(props.radius)) {
      internalStyle.overflow = 'hidden';
      internalStyle.borderRadius = addUnit(props.radius);
    }

    return internalStyle;
  }, []);
  useEffect(function () {
    if (imgRef.current && imgRef.current.complete) {
      setStatus({
        loading: false,
        error: false
      });
    }

    return function () {
      unmountedRef.current = true;
    };
  }, []);
  useUpdateEffect(function () {
    if (imgRef.current && !imgRef.current.complete) {
      setStatus({
        error: false,
        loading: true
      });
    }
  }, [props.src]);

  var onLoad = function onLoad(e) {
    if (!unmountedRef.current) {
      var _props$onLoad;

      setStatus({
        loading: false
      });
      (_props$onLoad = props.onLoad) === null || _props$onLoad === void 0 ? void 0 : _props$onLoad.call(props, e);
    }
  };

  var onError = function onError(e) {
    if (!unmountedRef.current) {
      var _props$onLoad2;

      setStatus({
        error: true,
        loading: false
      });
      (_props$onLoad2 = props.onLoad) === null || _props$onLoad2 === void 0 ? void 0 : _props$onLoad2.call(props, e);
    }
  };

  var renderLoadingIcon = function renderLoadingIcon() {
    if (typeof loadingIcon !== 'string') return loadingIcon;
    return /*#__PURE__*/React.createElement(Icon, {
      size: props.iconSize,
      name: loadingIcon,
      className: classnames(bem('loading-icon')),
      classPrefix: props.iconPrefix
    });
  };

  var renderErrorIcon = function renderErrorIcon() {
    if (typeof errorIcon !== 'string') return errorIcon;
    return /*#__PURE__*/React.createElement(Icon, {
      size: props.iconSize,
      name: errorIcon,
      className: classnames(bem('error-icon')),
      classPrefix: props.iconPrefix
    });
  };

  var renderPlaceholder = function renderPlaceholder() {
    if (status.loading && showLoading) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('loading')),
        onClick: props.onClick
      }, renderLoadingIcon());
    }

    if (status.error && showError) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('error')),
        onClick: props.onClick
      }, renderErrorIcon());
    }

    return null;
  };

  var renderImage = function renderImage() {
    if (status.error || !props.src) {
      return null;
    }

    var attrs = {
      className: classnames(bem('img')),
      style: {
        objectFit: fit
      }
    };
    return /*#__PURE__*/React.createElement("img", _extends({
      ref: imgRef,
      alt: props.alt || 'img',
      src: props.src,
      onLoad: onLoad,
      onError: onError
    }, attrs));
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classnames(props.className, bem({
      block: block,
      round: props.round
    })),
    style: style,
    onClick: props.onClick
  }, renderImage(), renderPlaceholder(), props.children);
};

Image.defaultProps = {
  fit: 'fill',
  errorIcon: 'photo-fail',
  loadingIcon: 'photo',
  showError: true,
  showLoading: true,
  block: true
};
export default Image;