import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext, useRef } from 'react';
import classnames from 'classnames';
import { getZIndexStyle } from '../utils';
import { BORDER_TOP_BOTTOM } from '../utils/constant';
import useHeight from '../hooks/use-height';
import TabbarContext from './TabbarContext';
import useMergedState from '../hooks/use-merged-state';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var Tabbar = function Tabbar(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('tabbar', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useMergedState = useMergedState({
    value: props.value,
    defaultValue: props.defaultValue
  }),
      _useMergedState2 = _slicedToArray(_useMergedState, 2),
      current = _useMergedState2[0],
      setCurrent = _useMergedState2[1];

  var root = useRef();
  var height = useHeight(root);

  var renderPlaceholder = function renderPlaceholder(renderContent) {
    return /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('placeholder')),
      style: {
        height: height
      }
    }, renderContent());
  }; // enable safe-area-inset-bottom by default when fixed


  var enableSafeArea = function enableSafeArea() {
    var _props$safeAreaInsetB;

    return (_props$safeAreaInsetB = props.safeAreaInsetBottom) !== null && _props$safeAreaInsetB !== void 0 ? _props$safeAreaInsetB : props.fixed;
  };

  var setActive = function setActive(active) {
    if (active !== props.value) {
      var _props$onChange;

      (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, active);
      setCurrent(active);
    }
  };

  var renderTabbar = function renderTabbar() {
    var _classnames;

    var fixed = props.fixed,
        zIndex = props.zIndex,
        border = props.border;
    return /*#__PURE__*/React.createElement(TabbarContext.Provider, {
      value: {
        parent: _objectSpread(_objectSpread({}, props), {}, {
          value: current
        })
      }
    }, /*#__PURE__*/React.createElement("div", {
      ref: root,
      style: _objectSpread(_objectSpread({}, props.style), getZIndexStyle(zIndex)),
      className: classnames(props.className, bem({
        fixed: fixed
      }), (_classnames = {}, _defineProperty(_classnames, BORDER_TOP_BOTTOM, border), _defineProperty(_classnames, 'rc-safe-area-bottom', enableSafeArea()), _classnames))
    }, React.Children.toArray(props.children).filter(Boolean).map(function (child, index) {
      return /*#__PURE__*/React.cloneElement(child, {
        setActive: setActive,
        index: index
      });
    })));
  };

  if (props.fixed && props.placeholder) {
    return renderPlaceholder(renderTabbar);
  }

  return renderTabbar();
};

Tabbar.defaultProps = {
  fixed: true,
  border: true,
  defaultValue: 0
};
export default Tabbar;