import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _typeof from "@babel/runtime/helpers/esm/typeof";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useMemo, useRef, useEffect, forwardRef, useImperativeHandle, useState, useContext } from 'react';
import classnames from 'classnames';
import useRefs from '../hooks/use-refs';
import useScrollParent from '../hooks/use-scroll-parent';
import useWindowSize from '../hooks/use-window-size';
import Sticky from '../sticky';
import TabsTitle from './TabsTitle';
import TabsContent from './TabsContent';
import TabsContext from './TabsContext';
import { addUnit, parseChildList, isHidden, isDef, unitToPx, scrollLeftTo, getElementTop, getVisibleHeight, scrollTopTo, getVisibleTop, setRootScrollTop } from '../utils';
import { callInterceptor } from '../utils/interceptor';
import { BORDER_TOP_BOTTOM } from '../utils/constant';
import { useSetState, useUpdateEffect } from '../hooks';
import useEventListener from '../hooks/use-event-listener';
import { isReachBottom } from './utils';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
import PopupContext from '../popup/PopupContext';
var Tabs = /*#__PURE__*/forwardRef(function (props, ref) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var popupContext = useContext(PopupContext);

  var _createNamespace = createNamespace('tabs', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var children = props.children,
      color = props.color,
      background = props.background;
  var root = useRef(null);

  var _useState = useState(null),
      _useState2 = _slicedToArray(_useState, 2),
      wrapRef = _useState2[0],
      setWrapRef = _useState2[1];

  var initChange = useRef(false);
  var lockScroll = useRef(false);
  var stickyFixed = useRef(false);
  var navRef = useRef(null);
  var scroller = useScrollParent(root);
  var windowSize = useWindowSize();

  var _useRefs = useRefs(),
      _useRefs2 = _slicedToArray(_useRefs, 2),
      titleRefs = _useRefs2[0],
      setTitleRefs = _useRefs2[1];

  var _useRefs3 = useRefs(),
      _useRefs4 = _slicedToArray(_useRefs3, 2),
      contentRefs = _useRefs4[0],
      setContentRefs = _useRefs4[1];

  var tabHeight = useMemo(function () {
    if (!wrapRef) return 0;
    return getVisibleHeight(wrapRef);
  }, [wrapRef]);
  var tabHeightRef = useRef(tabHeight);
  tabHeightRef.current = tabHeight;

  var _useSetState = useSetState({
    inited: false,
    position: '',
    currentIndex: -1,
    lineStyle: {
      backgroundColor: props.color
    }
  }),
      _useSetState2 = _slicedToArray(_useSetState, 2),
      state = _useSetState2[0],
      setState = _useSetState2[1];

  var childrenList = useMemo(function () {
    return parseChildList(props.children);
  }, [props.children]); // whether the nav is scrollable

  var scrollable = useMemo(function () {
    return childrenList.length > props.swipeThreshold || !props.ellipsis;
  }, [childrenList.length, props.swipeThreshold, props.ellipsis]);
  var navStyle = useMemo(function () {
    return {
      borderColor: color,
      background: background
    };
  }, [color, background]);

  var getTabName = function getTabName(tab, index) {
    var _tab$name;

    return (_tab$name = tab === null || tab === void 0 ? void 0 : tab.name) !== null && _tab$name !== void 0 ? _tab$name : index;
  };

  var currentName = useMemo(function () {
    var activeTab = childrenList[state.currentIndex];
    return activeTab && getTabName(activeTab, state.currentIndex);
  }, [state.currentIndex]);
  var offsetTopPx = useMemo(function () {
    return unitToPx(props.offsetTop);
  }, [props.offsetTop]); // scroll active tab into view

  var scrollIntoView = function scrollIntoView(immediate) {
    var nav = navRef.current;

    if (!scrollable || !nav || !titleRefs || !titleRefs[state.currentIndex]) {
      return;
    }

    var title = titleRefs[state.currentIndex];
    var to = title.offsetLeft - (nav.offsetWidth - title.offsetWidth) / 2;
    scrollLeftTo(nav, to, immediate ? 0 : +props.duration);
  };

  var setLine = function setLine(immediate) {
    var shouldAnimate = state.inited;
    if (immediate) shouldAnimate = false;
    var titles = titleRefs;
    var hidden = isHidden(root.current);

    if (!titles || !titles[state.currentIndex] || props.type !== 'line' || hidden) {
      return;
    }

    var title = titles[state.currentIndex];
    var lineWidth = props.lineWidth,
        lineHeight = props.lineHeight;
    var left = title.offsetLeft + title.offsetWidth / 2;
    var lineStyle = {
      width: addUnit(lineWidth),
      backgroundColor: props.color,
      transform: "translateX(".concat(left, "px) translateX(-50%)")
    };

    if (shouldAnimate) {
      lineStyle.transitionDuration = "".concat(props.duration, "ms");
    }

    if (isDef(lineHeight)) {
      var height = addUnit(lineHeight);
      lineStyle.height = height;
      lineStyle.borderRadius = height;
    }

    setState({
      lineStyle: lineStyle
    });
  };

  var findAvailableTab = function findAvailableTab(index) {
    var diff = index < state.currentIndex ? -1 : 1;

    while (index >= 0 && index < childrenList.length) {
      if (!childrenList[index].disabled) {
        return index;
      }

      index += diff;
    }

    return null;
  };

  var setCurrentIndex = function setCurrentIndex(currentIndex) {
    var newIndex = findAvailableTab(currentIndex);

    if (!isDef(newIndex)) {
      return;
    }

    var newTab = childrenList[newIndex];
    var newName = getTabName(newTab, newIndex);
    var shouldEmitChange = state.currentIndex !== null;
    setState({
      currentIndex: newIndex
    });

    if (!initChange.current) {
      initChange.current = true;
      return;
    }

    if (initChange.current) {
      if (shouldEmitChange) {
        var _props$onChange;

        (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, newName, newTab.title);
      }
    }
  }; // correct the index of active tab


  var setCurrentIndexByName = function setCurrentIndexByName(name) {
    var currentIndex = childrenList.findIndex(function (tab, index) {
      return getTabName(tab, index) === name;
    });
    setCurrentIndex(currentIndex < 0 ? 0 : currentIndex);
  };

  var scrollToCurrentContent = function scrollToCurrentContent(immediate, current) {
    if (props.scrollspy) {
      var target = contentRefs[current !== null && current !== void 0 ? current : state.currentIndex];

      if (target && scroller) {
        var to = getElementTop(target, scroller) - (offsetTopPx + tabHeightRef.current);
        lockScroll.current = true;
        scrollTopTo(scroller, to, immediate ? 0 : +props.duration, function () {
          lockScroll.current = false;
        });
      }
    }
  };

  var onClickTab = function onClickTab(item, index, event) {
    var _props$onClickTab;

    var title = item.title,
        _item$disabled = item.disabled,
        disabled = _item$disabled === void 0 ? false : _item$disabled;
    var name = getTabName(item, index);
    (_props$onClickTab = props.onClickTab) === null || _props$onClickTab === void 0 ? void 0 : _props$onClickTab.call(props, {
      name: name,
      title: title,
      event: event,
      disabled: disabled
    });
    if (disabled) return;
    callInterceptor({
      interceptor: props.beforeChange,
      args: [name],
      done: function done() {
        if (index !== state.currentIndex) {
          setCurrentIndex(index);
          scrollToCurrentContent(false, index);
        }
      }
    });
  };

  var scrollTo = function scrollTo(name) {
    setCurrentIndexByName(name);
    scrollToCurrentContent(true);
  };

  var getCurrentIndexOnScroll = function getCurrentIndexOnScroll() {
    var scrollOffset = offsetTopPx + tabHeightRef.current; // eslint-disable-next-line no-plusplus

    for (var index = 0; index < contentRefs.length; index++) {
      var $el = contentRefs[index];
      var top = getVisibleTop($el);

      if (top > scrollOffset) {
        return index === 0 ? 0 : index - 1;
      }
    }

    return titleRefs.length - 1;
  };

  var onScroll = function onScroll() {
    if (props.scrollspy && !lockScroll.current) {
      var index = getCurrentIndexOnScroll();

      if (_typeof(props.scrollspy) === 'object') {
        if (props.scrollspy.autoFocusLast && isReachBottom(props.scrollspy.reachBottomThreshold)) {
          index = titleRefs.length - 1;
        }
      }

      if (index !== state.currentIndex) {
        setCurrentIndex(index);
      }
    }
  };

  var onStickyScroll = function onStickyScroll(params) {
    var _props$onScroll;

    stickyFixed.current = params.isFixed;
    (_props$onScroll = props.onScroll) === null || _props$onScroll === void 0 ? void 0 : _props$onScroll.call(props, params);
  };

  var renderNav = function renderNav() {
    return childrenList.map(function (item, index) {
      return /*#__PURE__*/React.createElement(TabsTitle, {
        ref: setTitleRefs(index),
        key: item.key,
        dot: item.dot,
        type: props.type,
        badge: item.badge,
        title: item.title,
        color: props.color,
        style: item.titleStyle,
        className: item.titleClass,
        isActive: index === state.currentIndex,
        disabled: item.disabled,
        scrollable: scrollable,
        renderTitle: item.renderTitle,
        activeColor: props.titleActiveColor,
        inactiveColor: props.titleInactiveColor,
        showZeroBadge: item.showZeroBadge,
        onClick: function onClick(event) {
          onClickTab(item, index, event);
        }
      });
    });
  };

  var renderHeader = function renderHeader() {
    var type = props.type,
        border = props.border;
    return /*#__PURE__*/React.createElement("div", {
      ref: setWrapRef,
      className: classnames([bem('wrap', {
        scrollable: scrollable
      }), _defineProperty({}, BORDER_TOP_BOTTOM, type === 'line' && border)])
    }, /*#__PURE__*/React.createElement("div", {
      ref: navRef,
      role: "tablist",
      className: classnames(bem('nav', [type, {
        complete: scrollable
      }])),
      style: navStyle
    }, props.navRight, renderNav(), type === 'line' && /*#__PURE__*/React.createElement("div", {
      className: classnames(bem('line')),
      style: state.lineStyle
    }), props.navRight));
  };

  useUpdateEffect(function () {
    setLine();
  }, [props.color, windowSize.width]);
  useUpdateEffect(function () {
    if (props.active !== currentName) {
      setCurrentIndexByName(props.active);
    }
  }, [props.active]);
  useUpdateEffect(function () {
    if (state.inited) {
      setCurrentIndexByName(props.active || currentName);
      setLine();
      scrollIntoView(true);
    }
  }, [React.Children.count(children)]);
  useUpdateEffect(function () {
    scrollIntoView();
    setLine(); // scroll to correct position

    if (stickyFixed.current && !props.scrollspy) {
      setRootScrollTop(Math.ceil(getElementTop(root.current) - offsetTopPx));
    }
  }, [state.currentIndex]);

  var init = function init() {
    setCurrentIndexByName(props.active);
    scrollIntoView(true);
    setState({
      inited: true
    });
  };

  useEffect(function () {
    init();
  }, []);
  useUpdateEffect(function () {
    if (popupContext.visible) {
      setLine();
    }
  }, [popupContext.visible]);
  useEventListener('scroll', onScroll, {
    target: scroller,
    depends: [state.currentIndex]
  });
  useImperativeHandle(ref, function () {
    return {
      resize: setLine,
      scrollTo: scrollTo
    };
  });

  var onStickyChange = function onStickyChange() {
    setLine(true);
  };

  return /*#__PURE__*/React.createElement(TabsContext.Provider, {
    value: {
      props: props,
      currentName: currentName,
      scrollIntoView: scrollIntoView,
      setLine: setLine
    }
  }, /*#__PURE__*/React.createElement("div", {
    ref: root,
    className: classnames(props.className, bem([props.type]))
  }, props.sticky ? /*#__PURE__*/React.createElement(Sticky, {
    container: root,
    offsetTop: offsetTopPx,
    onChange: onStickyChange,
    onScroll: onStickyScroll
  }, renderHeader(), props.navBottom) : /*#__PURE__*/React.createElement(React.Fragment, null, renderHeader(), props.navBottom), /*#__PURE__*/React.createElement(TabsContent, {
    count: childrenList.length,
    inited: state.inited,
    animated: props.animated,
    duration: props.duration,
    swipeable: props.swipeable,
    lazyRender: props.lazyRender,
    currentIndex: state.currentIndex,
    onChange: setCurrentIndex
  }, React.Children.toArray(children).filter(Boolean).map(function (node, index) {
    return /*#__PURE__*/React.cloneElement(node, {
      index: index,
      ref: setContentRefs(index)
    });
  }))));
});
Tabs.defaultProps = {
  type: 'line',
  duration: 300,
  swipeThreshold: 5,
  offsetTop: 0,
  ellipsis: true,
  lazyRender: true,
  active: 0
};
export default Tabs;