import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useMemo, useRef, useContext } from 'react';
import classnames from 'classnames';
import { CSSTransition } from 'react-transition-group';
import Icon from '../icon';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var Tag = function Tag(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('tag', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var nodeRef = useRef(null);

  var onClose = function onClose(event) {
    event.stopPropagation();

    if (props.onClose) {
      props.onClose(event);
    }
  };

  var getStyle = useMemo(function () {
    if (props.plain) {
      return {
        color: props.textColor || props.color,
        borderColor: props.color
      };
    }

    return {
      color: props.textColor,
      background: props.color
    };
  }, [props.textColor, props.color, props.plain]);

  var renderTag = function renderTag() {
    var type = props.type,
        mark = props.mark,
        plain = props.plain,
        round = props.round,
        size = props.size,
        closeable = props.closeable;
    var classes = {
      mark: mark,
      plain: plain,
      round: round
    };

    if (size) {
      classes[size] = size;
    }

    var CloseIcon = closeable && /*#__PURE__*/React.createElement(Icon, {
      name: "cross",
      className: classnames(bem('close')),
      onClick: onClose
    });
    return /*#__PURE__*/React.createElement("span", {
      ref: nodeRef,
      style: _objectSpread(_objectSpread({}, getStyle), props.style),
      className: classnames(props.className, bem([classes, type])),
      onClick: props.onClick
    }, props.children, CloseIcon);
  };

  return /*#__PURE__*/React.createElement(CSSTransition, {
    nodeRef: nodeRef,
    classNames: "rc-fade",
    in: props.show,
    timeout: 300,
    unmountOnExit: true
  }, renderTag());
};

Tag.defaultProps = {
  show: true,
  type: 'default'
};
export default Tag;